@@ -1,22 +1,9 @@
-#  File ergm/R/InitConstraint.R
-#  Part of the statnet package, http://statnetproject.org
-#
-#  This software is distributed under the GPL-3 license.  It is free,
-#  open source, and has the attribution requirements (GPL Section 7) in
-#    http://statnetproject.org/attribution
-#
-# Copyright 2003 Mark S. Handcock, University of Washington
-#                David R. Hunter, Penn State University
-#                Carter T. Butts, University of California - Irvine
-#                Steven M. Goodreau, University of Washington
-#                Martina Morris, University of Washington
-# Copyright 2007 The statnet Development Team
-######################################################################
 ## List of which constraints make which constraints redundant.
 ConstraintImplications<-list(edges=character(0),
                              degrees=c("edges","indegrees","outdegrees","degreedist","bd"),
                              degreedist=c("edges","indegrees"),
                              indegreedist=c("edges"),
+                             outdegreedist=c("edges"),
                              bd=character(0),
                              indegrees=c("edges"),
                              outdegrees=c("edges"),
@@ -50,6 +37,13 @@ InitConstraint.indegreedist<-function(conlist){
    conlist
 }
 
+InitConstraint.outdegreedist<-function(conlist){
+   if (nargs()>1)
+     stop(paste("OutDegree distribution constraint does not take arguments at this time."), call.=FALSE)
+   conlist$outdegreedist<-list()
+   conlist
+}
+
 InitConstraint.bd<-function(conlist, attribs=0, maxout=0, maxin=0, minout=0, minin=0){
    if (nargs()>6)
      stop(paste("Bounded degrees constraint takes at most 5 arguments; ",nargs()-1," given.",sep=""), call.=FALSE)
