@@ -1,17 +1,3 @@
-#  File ergm/R/InitMHP.R
-#  Part of the statnet package, http://statnetproject.org
-#
-#  This software is distributed under the GPL-3 license.  It is free,
-#  open source, and has the attribution requirements (GPL Section 7) in
-#    http://statnetproject.org/attribution
-#
-# Copyright 2003 Mark S. Handcock, University of Washington
-#                David R. Hunter, Penn State University
-#                Carter T. Butts, University of California - Irvine
-#                Steven M. Goodreau, University of Washington
-#                Martina Morris, University of Washington
-# Copyright 2007 The statnet Development Team
-######################################################################
 InitMHP.randomtoggle <- function(arguments, nw, model) {
   MHproposal <- list(name = "randomtoggle", args=NULL, package="ergm")
   if(is.bipartite(nw)){
@@ -39,9 +25,9 @@ InitMHP.TNT10 <- function(arguments, nw, model) {
 InitMHP.CondDegree <- function(arguments, nw, model) {
   MHproposal <- list(name = "CondDegree", args=NULL, package="ergm")
   if (is.directed(nw)) {
-    print("Warning:  Using the 'degree' constraint with a directed network",
-          "is currently perilous.  We recommend that you use 'outdegree' or",
-          "'indegree' instead.")
+    cat("Warning:  Using the 'degree' constraint with a directed network\n",
+          "is currently perilous.  We recommend that you use 'outdegree' or\n",
+          "'indegree' instead.\n")
   }
   if(is.bipartite(nw)){
     MHproposal$name <- "BipartiteCondDegHexadToggles"
@@ -52,9 +38,9 @@ InitMHP.CondDegree <- function(arguments, nw, model) {
 InitMHP.CondDegreeDist <- function(arguments, nw, model) {
   MHproposal <- list(name = "CondDegreeDist", args=NULL, package="ergm")
   if (is.directed(nw)) {
-    print("Warning:  Using the 'degreedist' constraint with a directed network",
-          "is currently perilous.  We recommend that you use 'outdegree' or",
-          "'indegree' instead.")
+    cat("Warning:  Using the 'degreedist' constraint with a directed network\n",
+          "is currently perilous.  We recommend that you use 'outdegree' or\n",
+          "'indegree' instead.\n")
   }
   if(is.bipartite(nw)){
      MHproposal$name <- "BipartiteCondDegreeDist"
@@ -65,9 +51,22 @@ InitMHP.CondDegreeDist <- function(arguments, nw, model) {
 InitMHP.CondInDegreeDist <- function(arguments, nw, model) {
   MHproposal <- list(name = "CondInDegreeDist", args=NULL, package="ergm")
   if (!is.directed(nw)) {
-    print("Warning:  Using the 'indegreedist' constraint with an undirected network",
-          "is currently perilous.  We recommend that you use 'degreedist'",
-          " instead.")
+    cat("Warning:  Using the 'indegreedist' constraint with an undirected network\n",
+          "is currently perilous.  We recommend that you use 'degreedist'\n",
+          " instead.\n")
+  }
+  if(is.bipartite(nw)){
+     MHproposal$name <- "BipartiteCondDegreeDist"
+  }
+  MHproposal
+}
+
+InitMHP.CondOutDegreeDist <- function(arguments, nw, model) {
+  MHproposal <- list(name = "CondOutDegreeDist", args=NULL, package="ergm")
+  if (!is.directed(nw)) {
+    cat("Warning:  Using the 'outdegreedist' constraint with an undirected network\n",
+          "is currently perilous.  We recommend that you use 'degreedist'\n",
+          " instead.\n")
   }
   if(is.bipartite(nw)){
      MHproposal$name <- "BipartiteCondDegreeDist"
@@ -78,8 +77,8 @@ InitMHP.CondInDegreeDist <- function(arguments, nw, model) {
 #InitMHP.CondOutDegree <- function(arguments, nw, model) {
 #  MHproposal <- list(name = "CondOutDegree", args=NULL, package="ergm")
 #  if (!is.directed(nw)) {
-#    print("Warning:  The 'outdegree' constraint does not work with an",
-#          "undirected network.  Switching to 'degree' constraint.")
+#    cat("Warning:  The 'outdegree' constraint does not work with an\n",
+#          "undirected network.  Switching to 'degree' constraint.\n")
 #    return(InitMHP.CondDegree(arguments, nw, model))
 #  }
 #  MHproposal
@@ -88,8 +87,8 @@ InitMHP.CondInDegreeDist <- function(arguments, nw, model) {
 #InitMHP.CondInDegree <- function(arguments, nw, model) {
 #  MHproposal <- list(name = "CondInDegree", args=NULL, package="ergm")
 #  if (!is.directed(nw)) {
-#    print("Warning:  The 'indegree' constraint does not work with an",
-#          "undirected network.  Switching to 'degree' constraint.")
+#    cat("Warning:  The 'indegree' constraint does not work with an\n",
+#          "undirected network.  Switching to 'degree' constraint.\n")
 #    return(InitMHP.CondDegree(arguments, nw, model))
 #  }
 #  MHproposal
