@@ -1,17 +1,3 @@
-#  File ergm/R/check.ErgmTerm.R
-#  Part of the statnet package, http://statnetproject.org
-#
-#  This software is distributed under the GPL-3 license.  It is free,
-#  open source, and has the attribution requirements (GPL Section 7) in
-#    http://statnetproject.org/attribution
-#
-# Copyright 2003 Mark S. Handcock, University of Washington
-#                David R. Hunter, Penn State University
-#                Carter T. Butts, University of California - Irvine
-#                Steven M. Goodreau, University of Washington
-#                Martina Morris, University of Washington
-# Copyright 2007 The statnet Development Team
-######################################################################
 check.ErgmTerm <- function(nw, arglist, directed=NULL, bipartite=NULL,
                            varnames=NULL, vartypes=NULL,
                            defaultvalues=list(), required=NULL) {
@@ -128,6 +114,7 @@ get.InitErgm.fname <- function() {
   return(NULL)
 }
 
+# zerowarnings is now deprecated; it's been replaced by extremewarnings
 zerowarnings <- function(gs) {
   out <- gs==0
   if(any(out)) {
@@ -137,3 +124,25 @@ zerowarnings <- function(gs) {
   out
 }
 
+extremewarnings <- function(gs, minval=0, maxval=NULL) {
+  out <- rep(FALSE, times=length(gs))
+  if (!is.null(minval))  {
+    tmp <- (gs <= minval)
+    if (any(tmp)) {
+      out <- out | tmp
+      cat(" Warning:  These coefficients will be -Inf:\n")
+      cat(paste(names(gs)[tmp], collapse=", "), "\n")
+    }
+  }
+  if (!is.null(minval))  {
+    tmp <- (gs >= maxval)
+    if (any(tmp)) {
+      out <- out | tmp
+      cat(" Warning:  These coefficients will be +Inf:\n")
+      cat(paste(names(gs)[tmp], collapse=", "), "\n")
+    }
+  }
+  out
+}
+
+
