@@ -1,17 +1,3 @@
-#  File ergm/R/mcmc.diagnostics.ergm.R
-#  Part of the statnet package, http://statnetproject.org
-#
-#  This software is distributed under the GPL-3 license.  It is free,
-#  open source, and has the attribution requirements (GPL Section 7) in
-#    http://statnetproject.org/attribution
-#
-# Copyright 2003 Mark S. Handcock, University of Washington
-#                David R. Hunter, Penn State University
-#                Carter T. Butts, University of California - Irvine
-#                Steven M. Goodreau, University of Washington
-#                Martina Morris, University of Washington
-# Copyright 2007 The statnet Development Team
-######################################################################
 mcmc.diagnostics <- function(object, ...)
   UseMethod("mcmc.diagnostics")
 
@@ -60,7 +46,7 @@ mcmc.diagnostics.ergm <- function(object, sample="sample",
     if(is.null(object$formula) ){
      x0 <- rep(0,ncol(statsmatrix))
     }else{
-     if(!is.latent(object) ){
+#     if(!is.latent(object) ){
       if(sample=="missing"){
         x0 <- apply(statsmatrix.miss,2,mean)
       }else{
@@ -82,7 +68,7 @@ mcmc.diagnostics.ergm <- function(object, sample="sample",
       if(ncol(statsmatrix) < length(x0)){
        x0 <- x0[-c(1:(length(x0)-ncol(statsmatrix)))]
       }
-     }
+#     }
     }
   }
   attributes(statsmatrix)$class <- NULL
